# 43 "src/frontc/clexer.mll"
 
open Cparser
open Pretty
exception Eof
exception InternalError of string
module E = Errormsg
module H = Hashtbl

let currentLoc () = 
  let l, f, c = E.getPosition () in
  { Cabs.lineno   = l;
    Cabs.filename = f;
    Cabs.byteno   = c; }

(* Some debugging support for line numbers *)
let dbgToken (t: token) = 
  if false then begin
    ignore (E.log "%a" insert
              (match t with 
                IDENT (n, l) -> dprintf "IDENT(%s,%d)\n" n l.Cabs.lineno
              | LBRACE l -> dprintf "LBRACE(%d)\n" l.Cabs.lineno
              | RBRACE l -> dprintf "RBRACE(%d)\n" l.Cabs.lineno
              | IF l -> dprintf "IF(%d)\n" l.Cabs.lineno
              | SWITCH l -> dprintf "SWITCH(%d)\n" l.Cabs.lineno
              | RETURN l -> dprintf "RETURN(%d)\n" l.Cabs.lineno
              | _ -> nil));
    t
  end else
    t

(*
** Keyword hashtable
*)
let lexicon = H.create 211
let init_lexicon _ =
  H.clear lexicon;
  List.iter 
    (fun (key, builder) -> H.add lexicon key builder)
    [ ("auto", fun loc -> AUTO loc);
      ("const", fun loc -> CONST loc);
      ("__const", fun loc -> CONST loc);
      ("__const__", fun loc -> CONST loc);
      ("static", fun loc -> STATIC loc);
      ("extern", fun loc -> EXTERN loc);
      ("long", fun loc -> LONG loc);
      ("short", fun loc -> SHORT loc);
      ("register", fun loc -> REGISTER loc);
      ("signed", fun loc -> SIGNED loc);
      ("__signed", fun loc -> SIGNED loc);
      ("unsigned", fun loc -> UNSIGNED loc);
      ("volatile", fun loc -> VOLATILE loc);
      ("__volatile", fun loc -> VOLATILE loc);
      (* WW: see /usr/include/sys/cdefs.h for why __signed and __volatile
       * are accepted GCC-isms *)
      ("char", fun loc -> CHAR loc);
      ("int", fun loc -> INT loc);
      ("float", fun loc -> FLOAT loc);
      ("double", fun loc -> DOUBLE loc);
      ("void", fun loc -> VOID loc);
      ("enum", fun loc -> ENUM loc);
      ("struct", fun loc -> STRUCT loc);
      ("typedef", fun loc -> TYPEDEF loc);
      ("union", fun loc -> UNION loc);
      ("break", fun loc -> BREAK loc);
      ("continue", fun loc -> CONTINUE loc);
      ("goto", fun loc -> GOTO loc); 
      ("return", fun loc -> dbgToken (RETURN loc));
      ("switch", fun loc -> dbgToken (SWITCH loc));
      ("case", fun loc -> CASE loc); 
      ("default", fun loc -> DEFAULT loc);
      ("while", fun loc -> WHILE loc);  
      ("do", fun loc -> DO loc);  
      ("for", fun loc -> FOR loc);
      ("if", fun loc -> dbgToken (IF loc));
      ("else", fun _ -> ELSE);
      (*** Implementation specific keywords ***)
      ("__signed__", fun loc -> SIGNED loc);
      ("__inline__", fun loc -> INLINE loc);
      ("inline", fun loc -> INLINE loc); 
      ("__inline", fun loc -> INLINE loc);
      ("_inline", fun loc -> INLINE loc);
      ("__attribute__", fun loc -> ATTRIBUTE loc);
      ("__attribute", fun loc -> ATTRIBUTE loc);
(*
      ("__attribute_used__", fun loc -> ATTRIBUTE_USED loc);
*)
      ("__blockattribute__", fun _ -> BLOCKATTRIBUTE);
      ("__blockattribute", fun _ -> BLOCKATTRIBUTE);
      ("__asm__", fun loc -> ASM loc);
      ("asm", fun loc -> ASM loc);
      ("__typeof__", fun loc -> TYPEOF loc);
      ("__typeof", fun loc -> TYPEOF loc);
      ("typeof", fun loc -> TYPEOF loc); 
      ("__alignof", fun loc -> ALIGNOF loc);
      ("__alignof__", fun loc -> ALIGNOF loc);
      ("__volatile__", fun loc -> VOLATILE loc);
      ("__volatile", fun loc -> VOLATILE loc);

      ("__FUNCTION__", fun loc -> FUNCTION__ loc);
      ("__func__", fun loc -> FUNCTION__ loc); (* ISO 6.4.2.2 *)
      ("__PRETTY_FUNCTION__", fun loc -> PRETTY_FUNCTION__ loc);
      ("__label__", fun _ -> LABEL__);
      (*** weimer: GCC arcana ***)
      ("__restrict", fun loc -> RESTRICT loc);
      ("restrict", fun loc -> RESTRICT loc);
(*      ("__extension__", EXTENSION); *)
      (**** MS VC ***)
      ("__int64", fun _ -> INT64 (currentLoc ()));
      ("__int32", fun loc -> INT loc);
      ("_cdecl",  fun _ -> MSATTR ("_cdecl", currentLoc ())); 
      ("__cdecl", fun _ -> MSATTR ("__cdecl", currentLoc ()));
      ("_stdcall", fun _ -> MSATTR ("_stdcall", currentLoc ())); 
      ("__stdcall", fun _ -> MSATTR ("__stdcall", currentLoc ()));
      ("_fastcall", fun _ -> MSATTR ("_fastcall", currentLoc ())); 
      ("__fastcall", fun _ -> MSATTR ("__fastcall", currentLoc ()));
      ("__w64", fun _ -> MSATTR("__w64", currentLoc ()));
      ("__declspec", fun loc -> DECLSPEC loc);
      ("__forceinline", fun loc -> INLINE loc); (* !! we turn forceinline 
                                                 * into inline *)
      ("__try", fun loc -> TRY loc);
      ("__except", fun loc -> EXCEPT loc);
      ("__finally", fun loc -> FINALLY loc);
      (* weimer: some files produced by 'GCC -E' expect this type to be
       * defined *)
      ("__builtin_va_list", 
       fun _ -> NAMED_TYPE ("__builtin_va_list", currentLoc ()));
      ("__builtin_va_arg", fun loc -> BUILTIN_VA_ARG loc);
      ("__builtin_types_compatible_p", fun loc -> BUILTIN_TYPES_COMPAT loc);
      ("__builtin_offsetof", fun loc -> BUILTIN_OFFSETOF loc);
      (* On some versions of GCC __thread is a regular identifier *)
      ("__thread", fun loc -> 
                      if Machdep.__thread_is_keyword then 
                         THREAD loc
                       else 
                         IDENT ("__thread", loc));
    ]

(* Mark an identifier as a type name. The old mapping is preserved and will 
 * be reinstated when we exit this context *)
let add_type name =
   (* ignore (print_string ("adding type name " ^ name ^ "\n"));  *)
   H.add lexicon name (fun loc -> NAMED_TYPE (name, loc))

let context : string list list ref = ref []

let push_context _ = context := []::!context

let pop_context _ = 
  match !context with
    [] -> raise (InternalError "Empty context stack")
  | con::sub ->
		(context := sub;
		List.iter (fun name -> 
                           (* ignore (print_string ("removing lexicon for " ^ name ^ "\n")); *)
                            H.remove lexicon name) con)

(* Mark an identifier as a variable name. The old mapping is preserved and 
 * will be reinstated when we exit this context  *)
let add_identifier name =
  match !context with
    [] -> () (* Just ignore raise (InternalError "Empty context stack") *)
  | con::sub ->
      (context := (name::con)::sub;
       (*                print_string ("adding IDENT for " ^ name ^ "\n"); *)
       H.add lexicon name (fun loc -> 
         dbgToken (IDENT (name, loc))))


(*
** Useful primitives
*)
let scan_ident id =
  let here = currentLoc () in
  try (H.find lexicon id) here
  (* default to variable name, as opposed to type *)
  with Not_found -> dbgToken (IDENT (id, here))


(*
** Buffer processor
*)
 
let attribDepth = ref 0 (* Remembers the nesting level when parsing 
                         * attributes *)


let init ~(filename: string) : Lexing.lexbuf =
  attribDepth := 0;
  init_lexicon ();
  (* Inititialize the pointer in Errormsg *)
  Lexerhack.add_type := add_type;
  Lexerhack.push_context := push_context;
  Lexerhack.pop_context := pop_context;
  Lexerhack.add_identifier := add_identifier;
  E.startParsing filename


let finish () = 
  E.finishParsing ()

(*** Error handling ***)
let error msg =
  E.parse_error msg


(*** escape character management ***)
let scan_escape (char: char) : int64 =
  let result = match char with
    'n' -> '\n'
  | 'r' -> '\r'
  | 't' -> '\t'
  | 'b' -> '\b'
  | 'f' -> '\012'  (* ASCII code 12 *)
  | 'v' -> '\011'  (* ASCII code 11 *)
  | 'a' -> '\007'  (* ASCII code 7 *)
  | 'e' | 'E' -> '\027'  (* ASCII code 27. This is a GCC extension *)
  | '\'' -> '\''    
  | '"'-> '"'     (* '"' *)
  | '?' -> '?'
  | '(' when not !Cprint.msvcMode -> '('
  | '{' when not !Cprint.msvcMode -> '{'
  | '[' when not !Cprint.msvcMode -> '['
  | '%' when not !Cprint.msvcMode -> '%'
  | '\\' -> '\\' 
  | other -> error ("Unrecognized escape sequence: \\" ^ (String.make 1 other))
  in
  Int64.of_int (Char.code result)

let scan_hex_escape str =
  let radix = Int64.of_int 16 in
  let the_value = ref Int64.zero in
  (* start at character 2 to skip the \x *)
  for i = 2 to (String.length str) - 1 do
    let thisDigit = Cabs.valueOfDigit (String.get str i) in
    (* the_value := !the_value * 16 + thisDigit *)
    the_value := Int64.add (Int64.mul !the_value radix) thisDigit
  done;
  !the_value

let scan_oct_escape str =
  let radix = Int64.of_int 8 in
  let the_value = ref Int64.zero in
  (* start at character 1 to skip the \x *)
  for i = 1 to (String.length str) - 1 do
    let thisDigit = Cabs.valueOfDigit (String.get str i) in
    (* the_value := !the_value * 8 + thisDigit *)
    the_value := Int64.add (Int64.mul !the_value radix) thisDigit
  done;
  !the_value

let lex_hex_escape remainder lexbuf =
  let prefix = scan_hex_escape (Lexing.lexeme lexbuf) in
  prefix :: remainder lexbuf

let lex_oct_escape remainder lexbuf =
  let prefix = scan_oct_escape (Lexing.lexeme lexbuf) in
  prefix :: remainder lexbuf

let lex_simple_escape remainder lexbuf =
  let lexchar = Lexing.lexeme_char lexbuf 1 in
  let prefix = scan_escape lexchar in
  prefix :: remainder lexbuf

let lex_unescaped remainder lexbuf =
  let prefix = Int64.of_int (Char.code (Lexing.lexeme_char lexbuf 0)) in
  prefix :: remainder lexbuf

let make_char (i:int64):char =
  let min_val = Int64.zero in
  let max_val = Int64.of_int 255 in
  (* if i < 0 || i > 255 then error*)
  if compare i min_val < 0 || compare i max_val > 0 then begin
    let msg = Printf.sprintf "clexer:make_char: character 0x%Lx too big" i in
    error msg
  end;
  Char.chr (Int64.to_int i)


(* ISO standard locale-specific function to convert a wide character
 * into a sequence of normal characters. Here we work on strings. 
 * We convert L"Hi" to "H\000i\000" 
  matth: this seems unused.
let wbtowc wstr =
  let len = String.length wstr in 
  let dest = String.make (len * 2) '\000' in 
  for i = 0 to len-1 do 
    dest.[i*2] <- wstr.[i] ;
  done ;
  dest
*)

(* This function converst the "Hi" in L"Hi" to { L'H', L'i', L'\0' }
  matth: this seems unused.
let wstr_to_warray wstr =
  let len = String.length wstr in
  let res = ref "{ " in
  for i = 0 to len-1 do
    res := !res ^ (Printf.sprintf "L'%c', " wstr.[i])
  done ;
  res := !res ^ "}" ;
  !res
*)

(* Pragmas get explicit end-of-line tokens.
 * Elsewhere they are silently discarded as whitespace. *)
let pragmaLine = ref false


# 311 "src/frontc/clexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\183\255\184\255\079\000\101\000\192\000\195\255\196\255\
    \197\255\198\255\199\255\200\255\201\255\202\255\203\255\204\255\
    \205\255\035\000\076\000\079\000\080\000\165\000\081\000\082\000\
    \109\000\159\000\163\000\110\000\179\000\013\001\051\001\246\255\
    \124\001\248\255\199\001\250\255\001\000\252\255\206\000\029\001\
    \235\255\254\255\255\255\251\255\005\000\018\002\093\002\168\002\
    \243\002\062\003\137\003\212\003\031\004\106\004\181\004\000\005\
    \075\005\150\005\225\005\044\006\119\006\194\006\013\007\088\007\
    \163\007\238\007\245\255\247\255\059\008\092\001\093\008\049\001\
    \105\008\085\008\159\008\122\008\151\008\157\008\014\001\171\008\
    \050\001\071\008\063\001\172\008\085\001\084\008\244\255\242\008\
    \252\008\025\009\035\009\006\009\064\009\074\009\097\009\107\009\
    \126\009\164\009\099\000\137\000\048\001\202\009\234\009\244\009\
    \243\255\166\000\096\000\065\000\007\010\040\010\072\010\082\010\
    \162\000\239\255\225\255\092\000\105\000\096\000\003\000\240\255\
    \219\255\238\255\217\255\218\255\237\255\236\255\234\255\209\255\
    \233\255\210\255\232\255\231\255\224\255\153\000\230\255\223\255\
    \176\000\229\255\226\255\116\010\191\010\010\011\085\011\160\011\
    \142\000\130\000\140\000\139\000\158\000\174\000\170\000\184\000\
    \177\000\214\000\220\000\005\001\211\000\221\000\220\000\190\255\
    \234\000\237\000\232\000\238\000\236\000\241\000\229\000\189\255\
    \232\000\233\000\188\255\239\000\248\000\187\255\137\007\253\255\
    \047\001\018\012\241\255\252\000\006\001\003\012\123\008\047\001\
    \053\001\067\008\043\001\036\001\005\001\006\001\016\001\025\001\
    \021\001\025\001\056\001\164\008\030\012\061\001\051\001\052\001\
    \057\001\081\001\083\001\117\001\119\001\088\001\073\001\078\001\
    \110\001\107\001\115\001\150\001\191\001\158\001\150\001\145\001\
    \249\255\163\001\147\001\185\001\180\001\182\001\177\001\190\001\
    \221\001\223\001\225\001\234\001\241\001\222\001\237\001\010\002\
    \250\001\006\002\001\002\004\002\051\002\051\002\051\002\049\002\
    \045\002\055\002\062\002\083\002\065\002\070\002\077\002\092\002\
    \117\002\126\002\237\008\236\008\250\008\098\009\138\007\139\007\
    \133\008\041\012\062\010\102\012\125\012\101\010\095\008\157\012\
    \032\012\181\012\236\012\054\012\105\012\156\009\171\007\212\009\
    \133\002\132\002\115\002\122\002\061\013\204\012\138\013\176\013\
    \249\013\177\009\070\014\008\013\104\014\139\013\165\013\031\012\
    \133\014\166\013\175\013\129\014\120\008\174\013\185\008\138\009\
    \233\009\130\014\064\012\030\012\206\014\216\014\245\014\172\014\
    \214\012\255\014\035\013\028\015\148\013\072\015\110\015\156\002\
    \158\008\147\008\060\015\149\015\093\014\217\002\183\002\152\002\
    \180\015\213\015\245\015\038\015";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\070\000\072\000\070\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\033\000\035\000\034\000\049\000\047\000\048\000\043\000\
    \041\000\040\000\039\000\044\000\061\000\014\000\014\000\255\255\
    \070\000\255\255\070\000\255\255\072\000\255\255\002\000\042\000\
    \255\255\255\255\255\255\255\255\255\255\070\000\070\000\070\000\
    \070\000\070\000\070\000\006\000\070\000\070\000\070\000\063\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\069\000\255\255\255\255\255\255\255\255\011\000\014\000\
    \014\000\014\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\014\000\014\000\014\000\014\000\255\255\255\255\
    \011\000\255\255\011\000\255\255\011\000\255\255\011\000\255\255\
    \255\255\012\000\012\000\012\000\012\000\255\255\011\000\255\255\
    \255\255\012\000\012\000\012\000\255\255\255\255\011\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\027\000\255\255\255\255\
    \028\000\255\255\255\255\070\000\070\000\070\000\070\000\062\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\064\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \002\000\255\255\255\255\014\000\014\000\002\000\001\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\013\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\003\000\001\000\255\255\255\255\255\255\
    \255\255\004\000\002\000\003\000\001\000\002\000\255\255\004\000\
    \002\000\003\000\001\000\002\000\255\255\000\000\255\255\255\255\
    \002\000\255\255\255\255\255\255\255\255\255\255\010\000\010\000\
    \255\255\001\000\255\255\255\255\007\000\010\000\010\000\010\000\
    \009\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \010\000\010\000\010\000\010\000\255\255\007\000\255\255\007\000\
    \255\255\007\000\255\255\007\000\255\255\255\255\008\000\008\000\
    \008\000\008\000\255\255\007\000\255\255\008\000\008\000\008\000\
    \255\255\255\255\007\000\255\255";
  Lexing.lex_default = 
   "\001\000\000\000\000\000\255\255\255\255\255\255\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\000\000\255\255\000\000\255\255\000\000\255\255\255\255\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\255\255\000\000\000\000\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\000\000\255\255\255\255\000\000\175\000\000\000\
    \255\255\178\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\037\000\253\000\255\255\253\000\175\000\041\000\
    \043\000\037\000\255\255\255\255\255\255\255\255\043\000\037\000\
    \255\255\255\255\255\255\255\255\175\000\255\255\041\000\175\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\038\000\037\000\043\000\038\000\038\000\044\000\043\000\
    \000\000\000\000\044\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \038\000\027\000\031\000\035\000\119\000\023\000\021\000\033\000\
    \009\000\008\000\024\000\026\000\006\000\025\000\028\000\039\000\
    \030\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\015\000\007\000\019\000\017\000\018\000\016\000\
    \004\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\032\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\011\000\036\000\010\000\020\000\034\000\
    \138\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\005\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\013\000\022\000\012\000\014\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\135\000\136\000\133\000\132\000\131\000\128\000\126\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\125\000\114\000\104\000\104\000\003\000\106\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\145\000\129\000\123\000\127\000\120\000\107\000\
    \113\000\116\000\117\000\144\000\118\000\105\000\134\000\038\000\
    \146\000\147\000\038\000\038\000\124\000\122\000\104\000\115\000\
    \121\000\112\000\130\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\137\000\038\000\171\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\168\000\104\000\160\000\148\000\104\000\149\000\
    \002\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\104\000\150\000\151\000\152\000\003\000\
    \153\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\139\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\070\000\070\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\042\000\
    \154\000\155\000\156\000\157\000\041\000\158\000\159\000\161\000\
    \162\000\163\000\069\000\069\000\164\000\165\000\166\000\167\000\
    \169\000\072\000\040\000\170\000\172\000\173\000\042\000\070\000\
    \070\000\070\000\071\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\029\000\029\000\070\000\191\000\189\000\
    \175\000\175\000\069\000\069\000\190\000\037\000\069\000\069\000\
    \069\000\073\000\192\000\187\000\193\000\084\000\078\000\072\000\
    \175\000\186\000\071\000\070\000\069\000\104\000\194\000\095\000\
    \071\000\095\000\175\000\068\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\069\000\069\000\
    \069\000\195\000\069\000\188\000\105\000\085\000\066\000\073\000\
    \175\000\082\000\236\000\067\000\069\000\104\000\227\000\226\000\
    \071\000\222\000\175\000\068\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\217\000\213\000\
    \212\000\211\000\069\000\207\000\208\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\209\000\
    \206\000\210\000\043\000\003\000\205\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\086\000\035\000\214\000\215\000\216\000\218\000\219\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\046\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\220\000\221\000\033\000\223\000\045\000\224\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\225\000\067\000\031\000\228\000\
    \229\000\230\000\231\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\232\000\233\000\234\000\
    \235\000\003\000\066\000\053\000\003\000\003\000\003\000\052\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\237\000\
    \238\000\239\000\240\000\241\000\242\000\243\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \244\000\245\000\246\000\247\000\003\000\248\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\047\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\249\000\104\000\017\001\018\001\019\001\041\000\
    \062\001\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\067\000\067\000\000\000\000\000\003\000\
    \063\001\048\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\000\000\067\000\000\000\
    \000\000\000\000\000\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\067\000\000\000\
    \000\000\000\000\003\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\049\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\000\000\000\000\000\000\000\000\003\000\000\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\050\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
    \003\000\000\000\051\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\000\000\000\000\003\000\000\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\000\000\000\000\000\000\000\000\003\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\056\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\000\000\000\000\000\000\
    \000\000\003\000\000\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\054\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \000\000\000\000\000\000\000\000\003\000\000\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\055\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\000\000\000\000\000\000\000\000\003\000\
    \000\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\000\000\000\000\
    \000\000\000\000\003\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\057\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\000\000\000\000\000\000\000\000\003\000\000\000\003\000\
    \003\000\003\000\003\000\058\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
    \003\000\000\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\059\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\000\000\000\000\003\000\000\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\060\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\000\000\000\000\000\000\000\000\003\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \061\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\000\000\000\000\000\000\
    \000\000\003\000\000\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\062\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \000\000\000\000\000\000\000\000\003\000\000\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\063\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\000\000\041\000\042\000\042\000\000\000\000\000\
    \000\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\176\000\000\000\000\000\000\000\064\000\
    \000\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\000\000\000\000\
    \000\000\000\000\065\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \042\000\000\000\000\000\000\000\000\000\000\000\000\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\000\000\000\000\000\000\000\000\003\000\000\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\096\000\000\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\070\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\070\000\070\000\182\000\000\000\042\000\182\000\
    \182\000\255\255\041\000\255\255\069\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\070\000\
    \175\000\069\000\069\000\182\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\087\000\086\000\000\000\000\000\028\001\042\000\
    \070\000\086\000\082\000\255\255\069\000\196\000\069\000\186\000\
    \196\000\196\000\000\000\078\000\000\000\083\000\000\000\000\000\
    \175\000\069\000\069\000\007\001\000\000\027\001\082\000\069\000\
    \082\000\083\000\087\000\086\000\196\000\070\000\080\000\000\000\
    \000\000\086\000\082\000\070\000\000\000\070\000\069\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\029\000\
    \029\000\070\000\070\000\000\000\069\000\027\001\082\000\069\000\
    \000\000\001\001\069\000\079\000\069\000\000\000\081\000\028\001\
    \067\000\000\000\061\001\076\000\078\000\000\000\000\000\000\000\
    \069\000\069\000\078\000\067\000\075\000\255\255\252\000\042\000\
    \255\255\252\000\252\000\000\000\069\000\000\000\027\001\061\001\
    \078\000\082\000\069\000\252\000\069\000\036\001\252\000\252\000\
    \067\000\079\000\000\000\077\000\078\000\252\000\175\000\251\000\
    \069\000\069\000\078\000\067\000\075\000\000\000\000\000\000\000\
    \000\000\000\000\252\000\000\000\000\000\093\000\027\001\093\000\
    \078\000\082\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \000\000\089\000\086\000\000\000\091\000\000\000\091\000\000\000\
    \086\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\000\000\000\000\255\255\
    \000\000\089\000\086\000\000\000\000\000\000\000\000\000\000\000\
    \086\000\086\000\000\000\255\255\000\000\000\000\255\255\086\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\175\000\255\255\086\000\000\000\
    \000\000\086\000\000\000\000\000\086\000\000\000\000\000\086\000\
    \000\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\013\001\086\000\086\000\
    \013\001\013\001\000\000\000\000\086\000\086\000\108\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \028\001\000\000\025\001\000\000\013\001\025\001\025\001\108\000\
    \108\000\108\000\108\000\108\000\108\000\000\000\000\000\086\000\
    \000\000\000\000\000\000\000\000\000\000\086\000\000\000\027\001\
    \000\000\025\001\096\000\000\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\042\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\000\000\255\255\255\255\000\000\027\001\
    \099\000\000\000\000\000\000\000\101\000\103\000\036\001\103\000\
    \000\000\098\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\000\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\000\000\000\000\000\000\000\000\042\000\
    \100\000\000\000\000\000\000\000\101\000\000\000\000\000\028\001\
    \000\000\098\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\102\000\102\000\027\001\000\000\
    \086\000\000\000\000\000\016\001\000\000\000\000\086\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\027\001\000\000\
    \086\000\042\000\000\000\111\000\000\000\111\000\086\000\109\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\255\255\000\000\000\000\000\000\000\000\000\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\000\000\109\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\000\000\000\000\086\000\000\000\
    \000\000\000\000\000\000\000\000\086\000\175\000\175\000\175\000\
    \175\000\175\000\175\000\175\000\175\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\086\000\000\000\
    \000\000\000\000\000\000\000\000\086\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\000\000\000\000\003\000\255\255\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\140\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\000\000\000\000\000\000\000\000\003\000\000\000\
    \003\000\003\000\003\000\003\000\141\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\000\000\000\000\000\000\
    \000\000\003\000\000\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\142\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \000\000\000\000\000\000\000\000\003\000\000\000\003\000\003\000\
    \003\000\003\000\003\000\143\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\000\000\000\000\000\000\000\000\003\000\
    \000\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\182\000\042\000\000\000\182\000\182\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\196\000\
    \000\000\000\000\196\000\196\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\182\000\181\000\181\000\181\000\181\000\181\000\
    \181\000\181\000\181\000\181\000\181\000\000\000\196\000\000\000\
    \000\000\000\000\181\000\181\000\181\000\181\000\181\000\181\000\
    \181\000\181\000\181\000\181\000\028\001\028\001\000\000\184\000\
    \011\001\011\001\011\001\011\001\011\001\011\001\011\001\011\001\
    \183\000\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
    \002\001\000\000\000\000\027\001\027\001\203\000\175\000\175\000\
    \175\000\175\000\175\000\175\000\175\000\175\000\028\001\185\000\
    \000\000\000\000\013\001\000\000\040\001\013\001\013\001\000\000\
    \183\000\000\000\000\000\000\000\000\000\000\000\180\000\199\000\
    \000\000\003\001\179\000\027\001\027\001\027\001\000\000\202\000\
    \000\000\013\001\040\001\041\001\040\001\200\000\000\000\000\000\
    \197\000\201\000\000\000\198\000\040\001\204\000\004\001\004\001\
    \004\001\004\001\004\001\004\001\004\001\004\001\004\001\004\001\
    \000\000\003\001\000\000\000\000\000\000\027\001\000\000\004\001\
    \004\001\004\001\004\001\004\001\004\001\004\001\004\001\004\001\
    \004\001\004\001\004\001\004\001\004\001\004\001\004\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\004\001\004\001\
    \004\001\004\001\004\001\004\001\000\000\000\000\000\000\004\001\
    \004\001\004\001\004\001\004\001\004\001\008\001\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\004\001\004\001\
    \004\001\004\001\004\001\004\001\041\000\010\001\010\001\010\001\
    \010\001\010\001\010\001\010\001\010\001\010\001\010\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\009\001\010\001\010\001\
    \010\001\010\001\010\001\010\001\045\001\045\001\045\001\045\001\
    \045\001\045\001\045\001\045\001\045\001\045\001\047\001\047\001\
    \047\001\047\001\047\001\047\001\047\001\047\001\047\001\047\001\
    \000\000\000\000\255\255\000\000\000\000\009\001\010\001\010\001\
    \010\001\010\001\010\001\010\001\010\001\010\001\010\001\010\001\
    \010\001\010\001\010\001\010\001\010\001\010\001\000\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\010\001\010\001\010\001\
    \010\001\010\001\010\001\052\001\000\000\052\001\000\000\000\000\
    \051\001\051\001\051\001\051\001\051\001\051\001\051\001\051\001\
    \051\001\051\001\000\000\000\000\000\000\000\000\025\001\042\000\
    \000\000\025\001\025\001\000\000\000\000\010\001\010\001\010\001\
    \010\001\010\001\010\001\049\001\049\001\049\001\049\001\049\001\
    \049\001\049\001\049\001\049\001\049\001\025\001\000\000\216\000\
    \000\000\000\000\000\000\000\000\035\000\175\000\037\000\000\000\
    \000\000\255\255\000\000\021\001\000\000\023\001\022\001\022\001\
    \022\001\022\001\022\001\022\001\022\001\022\001\022\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \000\000\000\000\000\000\000\000\024\001\255\255\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \028\001\028\001\022\001\022\001\022\001\022\001\022\001\022\001\
    \022\001\022\001\022\001\022\001\051\001\051\001\051\001\051\001\
    \051\001\051\001\051\001\051\001\051\001\051\001\000\000\027\001\
    \027\001\000\000\000\000\028\001\028\001\000\000\030\001\042\001\
    \000\000\000\000\000\000\000\000\028\001\028\001\028\001\029\001\
    \032\001\032\001\032\001\032\001\032\001\032\001\032\001\032\001\
    \022\001\022\001\027\001\027\001\000\000\000\000\000\000\027\001\
    \027\001\041\001\038\001\027\001\027\001\027\001\031\001\043\001\
    \000\000\000\000\040\001\037\001\030\001\000\000\000\000\029\001\
    \000\000\000\000\000\000\036\001\036\001\029\001\000\000\000\000\
    \026\001\000\000\027\001\027\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\039\001\027\001\027\001\027\001\000\000\000\000\
    \000\000\000\000\040\001\000\000\031\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\036\001\036\001\029\001\000\000\000\000\
    \026\001\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\000\000\000\000\000\000\000\000\
    \043\000\000\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\053\001\000\000\054\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\054\001\054\001\054\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\054\001\
    \054\001\054\001\054\001\054\001\054\001\059\001\059\001\059\001\
    \059\001\059\001\059\001\059\001\059\001\059\001\059\001\000\000\
    \045\001\045\001\045\001\045\001\045\001\045\001\045\001\045\001\
    \045\001\045\001\000\000\000\000\000\000\000\000\000\000\054\001\
    \054\001\054\001\054\001\054\001\054\001\044\001\033\000\028\001\
    \028\001\000\000\000\000\028\001\033\000\032\001\032\001\032\001\
    \032\001\032\001\032\001\032\001\032\001\022\001\022\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\027\001\027\001\
    \000\000\000\000\027\001\000\000\000\000\044\001\033\000\000\000\
    \000\000\034\001\000\000\000\000\033\000\000\000\036\001\040\001\
    \000\000\000\000\033\001\000\000\047\001\047\001\047\001\047\001\
    \047\001\047\001\047\001\047\001\047\001\047\001\027\001\027\001\
    \000\000\000\000\027\001\000\000\000\000\037\001\000\000\000\000\
    \000\000\035\001\033\000\000\000\000\000\000\000\036\001\040\001\
    \033\000\050\001\033\001\050\001\000\000\000\000\049\001\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\049\001\049\001\
    \045\001\045\001\045\001\045\001\045\001\045\001\045\001\045\001\
    \045\001\045\001\033\000\000\000\000\000\000\000\000\000\000\000\
    \033\000\000\000\000\000\000\000\000\000\046\001\033\000\000\000\
    \048\001\000\000\048\001\000\000\033\000\047\001\047\001\047\001\
    \047\001\047\001\047\001\047\001\047\001\047\001\047\001\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\049\001\049\001\
    \049\001\000\000\000\000\000\000\000\000\046\001\033\000\000\000\
    \000\000\000\000\000\000\000\000\033\000\033\000\000\000\000\000\
    \000\000\000\000\000\000\033\000\051\001\051\001\051\001\051\001\
    \051\001\051\001\051\001\051\001\051\001\051\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \000\000\000\000\033\000\000\000\000\000\033\000\000\000\060\001\
    \033\000\060\001\000\000\033\000\059\001\059\001\059\001\059\001\
    \059\001\059\001\059\001\059\001\059\001\059\001\000\000\000\000\
    \064\001\064\001\064\001\064\001\064\001\064\001\064\001\064\001\
    \064\001\064\001\033\000\000\000\000\000\000\000\000\000\000\000\
    \033\000\064\001\064\001\064\001\064\001\064\001\064\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\053\001\000\000\054\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\054\001\054\001\054\001\
    \000\000\064\001\064\001\064\001\064\001\064\001\064\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\000\000\000\000\000\000\
    \000\000\000\000\056\001\000\000\000\000\000\000\058\001\000\000\
    \000\000\000\000\000\000\055\001\000\000\059\001\059\001\059\001\
    \059\001\059\001\059\001\059\001\059\001\059\001\059\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\000\000\000\000\000\000\
    \000\000\000\000\057\001\033\000\000\000\000\000\058\001\000\000\
    \000\000\033\000\000\000\055\001\064\001\064\001\064\001\064\001\
    \064\001\064\001\064\001\064\001\064\001\064\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\064\001\064\001\064\001\
    \064\001\064\001\064\001\033\000\000\000\000\000\000\000\000\000\
    \067\001\033\000\067\001\000\000\065\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\064\001\064\001\064\001\
    \064\001\064\001\064\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\065\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\033\000\000\000\000\000\000\000\000\000\
    \000\000\033\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\033\000\000\000\000\000\000\000\000\000\
    \000\000\033\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\036\000\000\000\000\000\036\000\044\000\
    \255\255\255\255\044\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\118\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \017\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\018\000\018\000\019\000\019\000\020\000\022\000\023\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\024\000\027\000\106\000\107\000\003\000\098\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\004\000\021\000\025\000\022\000\026\000\098\000\
    \112\000\115\000\116\000\004\000\117\000\099\000\133\000\038\000\
    \004\000\004\000\038\000\038\000\025\000\025\000\099\000\027\000\
    \026\000\028\000\021\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\136\000\038\000\144\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\145\000\105\000\146\000\147\000\099\000\148\000\
    \000\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\105\000\149\000\150\000\151\000\005\000\
    \152\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\029\000\078\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\039\000\
    \153\000\154\000\155\000\156\000\039\000\157\000\158\000\160\000\
    \161\000\162\000\029\000\078\000\163\000\164\000\165\000\166\000\
    \168\000\029\000\039\000\169\000\171\000\172\000\176\000\071\000\
    \080\000\030\000\029\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\082\000\179\000\180\000\
    \187\000\188\000\029\000\078\000\189\000\190\000\071\000\080\000\
    \030\000\029\000\191\000\183\000\192\000\071\000\080\000\030\000\
    \186\000\184\000\029\000\084\000\082\000\100\000\193\000\069\000\
    \030\000\069\000\184\000\030\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\071\000\080\000\
    \030\000\194\000\084\000\183\000\100\000\071\000\032\000\030\000\
    \186\000\084\000\197\000\032\000\082\000\100\000\198\000\199\000\
    \030\000\200\000\184\000\030\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\201\000\202\000\
    \203\000\205\000\084\000\206\000\207\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\208\000\
    \204\000\209\000\210\000\032\000\204\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\211\000\212\000\213\000\214\000\215\000\217\000\218\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\219\000\220\000\221\000\222\000\034\000\223\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\224\000\225\000\226\000\227\000\
    \228\000\229\000\230\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\231\000\232\000\233\000\
    \234\000\045\000\235\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\046\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\236\000\
    \237\000\238\000\239\000\240\000\241\000\242\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
    \243\000\244\000\245\000\246\000\046\000\247\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\248\000\249\000\016\001\017\001\018\001\019\001\
    \055\001\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\062\001\063\001\255\255\255\255\047\000\
    \055\001\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
    \047\000\047\000\047\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\255\255\061\001\255\255\
    \255\255\255\255\255\255\255\255\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\061\001\255\255\
    \255\255\255\255\048\000\255\255\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\255\255\255\255\255\255\255\255\049\000\255\255\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\255\255\255\255\255\255\255\255\
    \050\000\255\255\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\255\255\
    \255\255\255\255\255\255\051\000\255\255\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\255\255\255\255\255\255\255\255\052\000\255\255\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\255\255\255\255\255\255\
    \255\255\053\000\255\255\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \255\255\255\255\255\255\255\255\054\000\255\255\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\255\255\255\255\255\255\255\255\055\000\
    \255\255\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\255\255\255\255\
    \255\255\255\255\056\000\255\255\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\255\255\255\255\255\255\255\255\057\000\255\255\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\255\255\255\255\255\255\255\255\
    \058\000\255\255\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\255\255\
    \255\255\255\255\255\255\059\000\255\255\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\255\255\255\255\255\255\255\255\060\000\255\255\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\255\255\255\255\255\255\
    \255\255\061\000\255\255\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \255\255\255\255\255\255\255\255\062\000\255\255\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\255\255\174\000\254\000\255\000\255\255\255\255\
    \255\255\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\174\000\255\255\255\255\255\255\063\000\
    \255\255\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\255\255\255\255\
    \255\255\255\255\064\000\255\255\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \014\001\255\255\255\255\255\255\255\255\255\255\255\255\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\255\255\255\255\255\255\255\255\065\000\255\255\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\068\000\255\255\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\081\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\068\000\068\000\068\000\068\000\
    \068\000\068\000\085\000\073\000\182\000\255\255\006\001\182\000\
    \182\000\174\000\254\000\255\000\081\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\072\000\
    \185\000\085\000\073\000\182\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\070\000\070\000\255\255\255\255\036\001\000\001\
    \075\000\070\000\073\000\014\001\081\000\195\000\072\000\185\000\
    \195\000\195\000\255\255\081\000\255\255\072\000\255\255\255\255\
    \185\000\085\000\073\000\006\001\255\255\036\001\072\000\075\000\
    \085\000\073\000\070\000\070\000\195\000\076\000\075\000\255\255\
    \255\255\070\000\073\000\077\000\255\255\074\000\072\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\079\000\083\000\255\255\076\000\036\001\072\000\075\000\
    \255\255\000\001\077\000\076\000\074\000\255\255\075\000\038\001\
    \057\001\255\255\056\001\074\000\076\000\255\255\255\255\255\255\
    \079\000\083\000\077\000\056\001\074\000\251\000\250\000\250\000\
    \251\000\250\000\250\000\255\255\076\000\255\255\038\001\057\001\
    \079\000\083\000\077\000\252\000\074\000\038\001\252\000\252\000\
    \057\001\077\000\255\255\074\000\076\000\250\000\251\000\250\000\
    \079\000\083\000\077\000\056\001\074\000\255\255\255\255\255\255\
    \255\255\255\255\252\000\255\255\255\255\087\000\038\001\087\000\
    \079\000\083\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\091\000\091\000\
    \091\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \255\255\088\000\088\000\255\255\089\000\255\255\089\000\255\255\
    \088\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\255\255\255\255\006\001\
    \255\255\088\000\088\000\255\255\255\255\255\255\255\255\255\255\
    \088\000\090\000\255\255\253\000\255\255\255\255\253\000\090\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\093\000\093\000\093\000\093\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\253\000\000\001\092\000\255\255\
    \255\255\090\000\255\255\255\255\092\000\255\255\255\255\090\000\
    \255\255\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\095\000\095\000\095\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\013\001\092\000\094\000\
    \013\001\013\001\255\255\255\255\092\000\094\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\096\000\096\000\
    \039\001\255\255\025\001\255\255\013\001\025\001\025\001\096\000\
    \096\000\096\000\096\000\096\000\096\000\255\255\255\255\094\000\
    \255\255\255\255\255\255\255\255\255\255\094\000\255\255\039\001\
    \255\255\025\001\097\000\255\255\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\015\001\096\000\
    \096\000\096\000\096\000\096\000\096\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\255\255\251\000\250\000\255\255\039\001\
    \097\000\255\255\255\255\255\255\097\000\101\000\039\001\101\000\
    \255\255\097\000\101\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\255\255\097\000\097\000\097\000\
    \097\000\097\000\097\000\255\255\255\255\255\255\255\255\015\001\
    \097\000\255\255\255\255\255\255\097\000\255\255\255\255\040\001\
    \255\255\097\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\103\000\103\000\103\000\103\000\
    \103\000\103\000\103\000\103\000\103\000\103\000\040\001\255\255\
    \102\000\255\255\255\255\015\001\255\255\255\255\102\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \108\000\108\000\108\000\108\000\108\000\108\000\040\001\255\255\
    \102\000\015\001\255\255\109\000\255\255\109\000\102\000\108\000\
    \109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
    \109\000\109\000\253\000\255\255\255\255\255\255\255\255\255\255\
    \108\000\108\000\108\000\108\000\108\000\108\000\002\001\002\001\
    \002\001\002\001\002\001\002\001\002\001\002\001\255\255\108\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\111\000\111\000\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\111\000\255\255\255\255\110\000\255\255\
    \255\255\255\255\255\255\255\255\110\000\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\110\000\255\255\
    \255\255\255\255\255\255\255\255\110\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\255\255\
    \255\255\255\255\255\255\139\000\015\001\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\255\255\255\255\255\255\255\255\140\000\255\255\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\255\255\255\255\255\255\
    \255\255\141\000\255\255\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \255\255\255\255\255\255\255\255\142\000\255\255\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\255\255\255\255\255\255\255\255\143\000\
    \255\255\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\177\000\177\000\255\255\177\000\177\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\196\000\
    \255\255\255\255\196\000\196\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\177\000\181\000\181\000\181\000\181\000\181\000\
    \181\000\181\000\181\000\181\000\181\000\255\255\196\000\255\255\
    \255\255\255\255\177\000\177\000\177\000\177\000\177\000\177\000\
    \177\000\177\000\177\000\177\000\043\001\031\001\255\255\181\000\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \181\000\001\001\001\001\001\001\001\001\001\001\001\001\001\001\
    \001\001\255\255\255\255\043\001\031\001\196\000\011\001\011\001\
    \011\001\011\001\011\001\011\001\011\001\011\001\042\001\181\000\
    \255\255\255\255\012\001\255\255\031\001\012\001\012\001\255\255\
    \181\000\255\255\255\255\255\255\255\255\255\255\177\000\196\000\
    \255\255\001\001\177\000\043\001\031\001\042\001\255\255\196\000\
    \255\255\012\001\043\001\031\001\042\001\196\000\255\255\255\255\
    \196\000\196\000\255\255\196\000\031\001\196\000\003\001\003\001\
    \003\001\003\001\003\001\003\001\003\001\003\001\003\001\003\001\
    \255\255\001\001\255\255\255\255\255\255\042\001\255\255\003\001\
    \003\001\003\001\003\001\003\001\003\001\004\001\004\001\004\001\
    \004\001\004\001\004\001\004\001\004\001\004\001\004\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\004\001\004\001\
    \004\001\004\001\004\001\004\001\255\255\255\255\255\255\003\001\
    \003\001\003\001\003\001\003\001\003\001\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\004\001\004\001\
    \004\001\004\001\004\001\004\001\012\001\009\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\007\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\021\001\021\001\021\001\021\001\
    \021\001\021\001\021\001\021\001\021\001\021\001\048\001\048\001\
    \048\001\048\001\048\001\048\001\048\001\048\001\048\001\048\001\
    \255\255\255\255\177\000\255\255\255\255\007\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\010\001\010\001\010\001\010\001\
    \010\001\010\001\010\001\010\001\010\001\010\001\255\255\255\255\
    \255\255\001\001\255\255\255\255\255\255\010\001\010\001\010\001\
    \010\001\010\001\010\001\027\001\255\255\027\001\255\255\255\255\
    \027\001\027\001\027\001\027\001\027\001\027\001\027\001\027\001\
    \027\001\027\001\255\255\255\255\255\255\255\255\020\001\020\001\
    \255\255\020\001\020\001\255\255\255\255\010\001\010\001\010\001\
    \010\001\010\001\010\001\050\001\050\001\050\001\050\001\050\001\
    \050\001\050\001\050\001\050\001\050\001\020\001\255\255\020\001\
    \255\255\255\255\255\255\255\255\020\001\020\001\020\001\255\255\
    \255\255\012\001\255\255\020\001\255\255\020\001\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\020\001\
    \255\255\255\255\255\255\255\255\020\001\007\001\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\020\001\
    \020\001\020\001\020\001\020\001\020\001\020\001\020\001\020\001\
    \022\001\029\001\022\001\022\001\022\001\022\001\022\001\022\001\
    \022\001\022\001\022\001\022\001\052\001\052\001\052\001\052\001\
    \052\001\052\001\052\001\052\001\052\001\052\001\255\255\022\001\
    \029\001\255\255\255\255\030\001\033\001\255\255\022\001\029\001\
    \255\255\255\255\255\255\255\255\037\001\034\001\023\001\022\001\
    \023\001\023\001\023\001\023\001\023\001\023\001\023\001\023\001\
    \023\001\023\001\030\001\033\001\255\255\255\255\255\255\022\001\
    \029\001\030\001\033\001\037\001\034\001\023\001\022\001\029\001\
    \255\255\255\255\030\001\034\001\023\001\255\255\255\255\022\001\
    \255\255\255\255\255\255\037\001\034\001\023\001\255\255\255\255\
    \023\001\255\255\030\001\033\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\033\001\037\001\034\001\023\001\255\255\255\255\
    \255\255\255\255\030\001\255\255\023\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\037\001\034\001\023\001\255\255\255\255\
    \023\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\255\255\255\255\255\255\255\255\
    \024\001\255\255\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\024\001\024\001\024\001\024\001\
    \024\001\024\001\024\001\024\001\026\001\255\255\026\001\026\001\
    \026\001\026\001\026\001\026\001\026\001\026\001\026\001\026\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\026\001\
    \026\001\026\001\026\001\026\001\026\001\060\001\060\001\060\001\
    \060\001\060\001\060\001\060\001\060\001\060\001\060\001\255\255\
    \028\001\028\001\028\001\028\001\028\001\028\001\028\001\028\001\
    \028\001\028\001\255\255\255\255\255\255\255\255\255\255\026\001\
    \026\001\026\001\026\001\026\001\026\001\028\001\028\001\035\001\
    \041\001\255\255\255\255\032\001\028\001\032\001\032\001\032\001\
    \032\001\032\001\032\001\032\001\032\001\032\001\032\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\035\001\041\001\
    \255\255\255\255\032\001\255\255\255\255\028\001\028\001\255\255\
    \255\255\032\001\255\255\255\255\028\001\255\255\035\001\041\001\
    \255\255\255\255\032\001\255\255\047\001\047\001\047\001\047\001\
    \047\001\047\001\047\001\047\001\047\001\047\001\035\001\041\001\
    \255\255\255\255\032\001\255\255\255\255\035\001\255\255\255\255\
    \255\255\032\001\047\001\255\255\255\255\255\255\035\001\041\001\
    \047\001\044\001\032\001\044\001\255\255\255\255\044\001\044\001\
    \044\001\044\001\044\001\044\001\044\001\044\001\044\001\044\001\
    \045\001\045\001\045\001\045\001\045\001\045\001\045\001\045\001\
    \045\001\045\001\047\001\255\255\255\255\255\255\255\255\255\255\
    \047\001\255\255\255\255\255\255\255\255\045\001\045\001\255\255\
    \046\001\255\255\046\001\255\255\045\001\046\001\046\001\046\001\
    \046\001\046\001\046\001\046\001\046\001\046\001\046\001\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\049\001\049\001\
    \049\001\255\255\255\255\255\255\255\255\045\001\045\001\255\255\
    \255\255\255\255\255\255\255\255\045\001\049\001\255\255\255\255\
    \255\255\255\255\255\255\049\001\051\001\051\001\051\001\051\001\
    \051\001\051\001\051\001\051\001\051\001\051\001\067\001\067\001\
    \067\001\067\001\067\001\067\001\067\001\067\001\067\001\067\001\
    \255\255\255\255\051\001\255\255\255\255\049\001\255\255\058\001\
    \051\001\058\001\255\255\049\001\058\001\058\001\058\001\058\001\
    \058\001\058\001\058\001\058\001\058\001\058\001\255\255\255\255\
    \053\001\053\001\053\001\053\001\053\001\053\001\053\001\053\001\
    \053\001\053\001\051\001\255\255\255\255\255\255\255\255\255\255\
    \051\001\053\001\053\001\053\001\053\001\053\001\053\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\054\001\255\255\054\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\054\001\054\001\054\001\
    \255\255\053\001\053\001\053\001\053\001\053\001\053\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\255\255\255\255\255\255\
    \255\255\255\255\054\001\255\255\255\255\255\255\054\001\255\255\
    \255\255\255\255\255\255\054\001\255\255\059\001\059\001\059\001\
    \059\001\059\001\059\001\059\001\059\001\059\001\059\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\255\255\255\255\255\255\
    \255\255\255\255\054\001\059\001\255\255\255\255\054\001\255\255\
    \255\255\059\001\255\255\054\001\064\001\064\001\064\001\064\001\
    \064\001\064\001\064\001\064\001\064\001\064\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\064\001\064\001\064\001\
    \064\001\064\001\064\001\059\001\255\255\255\255\255\255\255\255\
    \065\001\059\001\065\001\255\255\064\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\064\001\064\001\064\001\
    \064\001\064\001\064\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\064\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\066\001\255\255\255\255\255\255\255\255\
    \255\255\066\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\066\001\255\255\255\255\255\255\255\255\
    \255\255\066\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code = 
   "";
  Lexing.lex_backtrk_code = 
   "";
  Lexing.lex_default_code = 
   "";
  Lexing.lex_trans_code = 
   "";
  Lexing.lex_check_code = 
   "";
  Lexing.lex_code = 
   "";
}

let rec initial lexbuf =
    __ocaml_lex_initial_rec lexbuf 0
and __ocaml_lex_initial_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 392 "src/frontc/clexer.mll"
               ( let _ = comment lexbuf in 
                                          initial lexbuf)
# 1549 "src/frontc/clexer.ml"

  | 1 ->
# 394 "src/frontc/clexer.mll"
                                        ( endline lexbuf )
# 1554 "src/frontc/clexer.ml"

  | 2 ->
# 395 "src/frontc/clexer.mll"
           (initial lexbuf)
# 1559 "src/frontc/clexer.ml"

  | 3 ->
# 396 "src/frontc/clexer.mll"
                                        ( E.newline ();
                                          if !pragmaLine then
                                            begin
                                              pragmaLine := false;
                                              PRAGMA_EOL
                                            end
                                          else
                                            initial lexbuf )
# 1571 "src/frontc/clexer.ml"

  | 4 ->
# 404 "src/frontc/clexer.mll"
                                        (
                                          E.newline ();
                                          initial lexbuf
                                        )
# 1579 "src/frontc/clexer.ml"

  | 5 ->
# 408 "src/frontc/clexer.mll"
         ( hash lexbuf)
# 1584 "src/frontc/clexer.ml"

  | 6 ->
# 409 "src/frontc/clexer.mll"
                                   ( PRAGMA (currentLoc ()) )
# 1589 "src/frontc/clexer.ml"

  | 7 ->
# 410 "src/frontc/clexer.mll"
          ( CST_CHAR (chr lexbuf, currentLoc ()))
# 1594 "src/frontc/clexer.ml"

  | 8 ->
# 411 "src/frontc/clexer.mll"
          ( CST_WCHAR (chr lexbuf, currentLoc ()) )
# 1599 "src/frontc/clexer.ml"

  | 9 ->
# 412 "src/frontc/clexer.mll"
         ( (* '"' *)
(* matth: BUG:  this could be either a regular string or a wide string.
 *  e.g. if it's the "world" in 
 *     L"Hello, " "world"
 *  then it should be treated as wide even though there's no L immediately
 *  preceding it.  See test/small1/wchar5.c for a failure case. *)
                                          try CST_STRING (str lexbuf, currentLoc ())
                                          with e -> 
                                             raise (InternalError 
                                                     ("str: " ^ 
                                                      Printexc.to_string e)))
# 1614 "src/frontc/clexer.ml"

  | 10 ->
# 423 "src/frontc/clexer.mll"
           ( (* weimer: wchar_t string literal *)
                                          try CST_WSTRING(str lexbuf, currentLoc ())
                                          with e -> 
                                             raise (InternalError 
                                                     ("wide string: " ^ 
                                                      Printexc.to_string e)))
# 1624 "src/frontc/clexer.ml"

  | 11 ->
# 429 "src/frontc/clexer.mll"
             (CST_FLOAT (Lexing.lexeme lexbuf, currentLoc ()))
# 1629 "src/frontc/clexer.ml"

  | 12 ->
# 430 "src/frontc/clexer.mll"
            (CST_INT (Lexing.lexeme lexbuf, currentLoc ()))
# 1634 "src/frontc/clexer.ml"

  | 13 ->
# 431 "src/frontc/clexer.mll"
            (CST_INT (Lexing.lexeme lexbuf, currentLoc ()))
# 1639 "src/frontc/clexer.ml"

  | 14 ->
# 432 "src/frontc/clexer.mll"
            (CST_INT (Lexing.lexeme lexbuf, currentLoc ()))
# 1644 "src/frontc/clexer.ml"

  | 15 ->
# 433 "src/frontc/clexer.mll"
             (EOF)
# 1649 "src/frontc/clexer.ml"

  | 16 ->
# 434 "src/frontc/clexer.mll"
           (ELLIPSIS)
# 1654 "src/frontc/clexer.ml"

  | 17 ->
# 435 "src/frontc/clexer.mll"
          (PLUS_EQ)
# 1659 "src/frontc/clexer.ml"

  | 18 ->
# 436 "src/frontc/clexer.mll"
          (MINUS_EQ)
# 1664 "src/frontc/clexer.ml"

  | 19 ->
# 437 "src/frontc/clexer.mll"
          (STAR_EQ)
# 1669 "src/frontc/clexer.ml"

  | 20 ->
# 438 "src/frontc/clexer.mll"
          (SLASH_EQ)
# 1674 "src/frontc/clexer.ml"

  | 21 ->
# 439 "src/frontc/clexer.mll"
          (PERCENT_EQ)
# 1679 "src/frontc/clexer.ml"

  | 22 ->
# 440 "src/frontc/clexer.mll"
          (PIPE_EQ)
# 1684 "src/frontc/clexer.ml"

  | 23 ->
# 441 "src/frontc/clexer.mll"
          (AND_EQ)
# 1689 "src/frontc/clexer.ml"

  | 24 ->
# 442 "src/frontc/clexer.mll"
          (CIRC_EQ)
# 1694 "src/frontc/clexer.ml"

  | 25 ->
# 443 "src/frontc/clexer.mll"
           (INF_INF_EQ)
# 1699 "src/frontc/clexer.ml"

  | 26 ->
# 444 "src/frontc/clexer.mll"
           (SUP_SUP_EQ)
# 1704 "src/frontc/clexer.ml"

  | 27 ->
# 445 "src/frontc/clexer.mll"
          (INF_INF)
# 1709 "src/frontc/clexer.ml"

  | 28 ->
# 446 "src/frontc/clexer.mll"
          (SUP_SUP)
# 1714 "src/frontc/clexer.ml"

  | 29 ->
# 447 "src/frontc/clexer.mll"
           (EQ_EQ)
# 1719 "src/frontc/clexer.ml"

  | 30 ->
# 448 "src/frontc/clexer.mll"
           (EXCLAM_EQ)
# 1724 "src/frontc/clexer.ml"

  | 31 ->
# 449 "src/frontc/clexer.mll"
          (INF_EQ)
# 1729 "src/frontc/clexer.ml"

  | 32 ->
# 450 "src/frontc/clexer.mll"
          (SUP_EQ)
# 1734 "src/frontc/clexer.ml"

  | 33 ->
# 451 "src/frontc/clexer.mll"
          (EQ)
# 1739 "src/frontc/clexer.ml"

  | 34 ->
# 452 "src/frontc/clexer.mll"
          (INF)
# 1744 "src/frontc/clexer.ml"

  | 35 ->
# 453 "src/frontc/clexer.mll"
          (SUP)
# 1749 "src/frontc/clexer.ml"

  | 36 ->
# 454 "src/frontc/clexer.mll"
          (PLUS_PLUS (currentLoc ()))
# 1754 "src/frontc/clexer.ml"

  | 37 ->
# 455 "src/frontc/clexer.mll"
          (MINUS_MINUS (currentLoc ()))
# 1759 "src/frontc/clexer.ml"

  | 38 ->
# 456 "src/frontc/clexer.mll"
          (ARROW)
# 1764 "src/frontc/clexer.ml"

  | 39 ->
# 457 "src/frontc/clexer.mll"
          (PLUS (currentLoc ()))
# 1769 "src/frontc/clexer.ml"

  | 40 ->
# 458 "src/frontc/clexer.mll"
          (MINUS (currentLoc ()))
# 1774 "src/frontc/clexer.ml"

  | 41 ->
# 459 "src/frontc/clexer.mll"
          (STAR (currentLoc ()))
# 1779 "src/frontc/clexer.ml"

  | 42 ->
# 460 "src/frontc/clexer.mll"
          (SLASH)
# 1784 "src/frontc/clexer.ml"

  | 43 ->
# 461 "src/frontc/clexer.mll"
          (PERCENT)
# 1789 "src/frontc/clexer.ml"

  | 44 ->
# 462 "src/frontc/clexer.mll"
         (EXCLAM (currentLoc ()))
# 1794 "src/frontc/clexer.ml"

  | 45 ->
# 463 "src/frontc/clexer.mll"
          (AND_AND (currentLoc ()))
# 1799 "src/frontc/clexer.ml"

  | 46 ->
# 464 "src/frontc/clexer.mll"
          (PIPE_PIPE)
# 1804 "src/frontc/clexer.ml"

  | 47 ->
# 465 "src/frontc/clexer.mll"
          (AND (currentLoc ()))
# 1809 "src/frontc/clexer.ml"

  | 48 ->
# 466 "src/frontc/clexer.mll"
          (PIPE)
# 1814 "src/frontc/clexer.ml"

  | 49 ->
# 467 "src/frontc/clexer.mll"
          (CIRC)
# 1819 "src/frontc/clexer.ml"

  | 50 ->
# 468 "src/frontc/clexer.mll"
          (QUEST)
# 1824 "src/frontc/clexer.ml"

  | 51 ->
# 469 "src/frontc/clexer.mll"
          (COLON)
# 1829 "src/frontc/clexer.ml"

  | 52 ->
# 470 "src/frontc/clexer.mll"
               (TILDE (currentLoc ()))
# 1834 "src/frontc/clexer.ml"

  | 53 ->
# 472 "src/frontc/clexer.mll"
               (dbgToken (LBRACE (currentLoc ())))
# 1839 "src/frontc/clexer.ml"

  | 54 ->
# 473 "src/frontc/clexer.mll"
               (dbgToken (RBRACE (currentLoc ())))
# 1844 "src/frontc/clexer.ml"

  | 55 ->
# 474 "src/frontc/clexer.mll"
          (LBRACKET)
# 1849 "src/frontc/clexer.ml"

  | 56 ->
# 475 "src/frontc/clexer.mll"
          (RBRACKET)
# 1854 "src/frontc/clexer.ml"

  | 57 ->
# 476 "src/frontc/clexer.mll"
               (dbgToken (LPAREN (currentLoc ())) )
# 1859 "src/frontc/clexer.ml"

  | 58 ->
# 477 "src/frontc/clexer.mll"
          (RPAREN)
# 1864 "src/frontc/clexer.ml"

  | 59 ->
# 478 "src/frontc/clexer.mll"
               (dbgToken (SEMICOLON (currentLoc ())) )
# 1869 "src/frontc/clexer.ml"

  | 60 ->
# 479 "src/frontc/clexer.mll"
          (COMMA)
# 1874 "src/frontc/clexer.ml"

  | 61 ->
# 480 "src/frontc/clexer.mll"
          (DOT)
# 1879 "src/frontc/clexer.ml"

  | 62 ->
# 481 "src/frontc/clexer.mll"
             (SIZEOF (currentLoc ()))
# 1884 "src/frontc/clexer.ml"

  | 63 ->
# 482 "src/frontc/clexer.mll"
                                        ( if !Cprint.msvcMode then 
                                             MSASM (msasm lexbuf, currentLoc ()) 
                                          else (ASM (currentLoc ())) )
# 1891 "src/frontc/clexer.ml"

  | 64 ->
# 487 "src/frontc/clexer.mll"
                                        (AT_TRANSFORM (currentLoc ()))
# 1896 "src/frontc/clexer.ml"

  | 65 ->
# 488 "src/frontc/clexer.mll"
                                        (AT_TRANSFORMEXPR (currentLoc ()))
# 1901 "src/frontc/clexer.ml"

  | 66 ->
# 489 "src/frontc/clexer.mll"
                                        (AT_SPECIFIER (currentLoc ()))
# 1906 "src/frontc/clexer.ml"

  | 67 ->
# 490 "src/frontc/clexer.mll"
                                        (AT_EXPR (currentLoc ()))
# 1911 "src/frontc/clexer.ml"

  | 68 ->
# 491 "src/frontc/clexer.mll"
                                        (AT_NAME)
# 1916 "src/frontc/clexer.ml"

  | 69 ->
# 495 "src/frontc/clexer.mll"
                                        (initial lexbuf )
# 1921 "src/frontc/clexer.ml"

  | 70 ->
# 496 "src/frontc/clexer.mll"
           (scan_ident (Lexing.lexeme lexbuf))
# 1926 "src/frontc/clexer.ml"

  | 71 ->
# 497 "src/frontc/clexer.mll"
         (EOF)
# 1931 "src/frontc/clexer.ml"

  | 72 ->
# 498 "src/frontc/clexer.mll"
       (E.parse_error
						"Invalid symbol"
						(Lexing.lexeme_start lexbuf)
						(Lexing.lexeme_end lexbuf);
						initial lexbuf)
# 1940 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_initial_rec lexbuf __ocaml_lex_state

and comment lexbuf =
    __ocaml_lex_comment_rec lexbuf 174
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 505 "src/frontc/clexer.mll"
                     ( () )
# 1951 "src/frontc/clexer.ml"

  | 1 ->
# 506 "src/frontc/clexer.mll"
                                        ( E.newline (); comment lexbuf )
# 1956 "src/frontc/clexer.ml"

  | 2 ->
# 507 "src/frontc/clexer.mll"
         ( comment lexbuf )
# 1961 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and hash lexbuf =
    __ocaml_lex_hash_rec lexbuf 177
and __ocaml_lex_hash_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 511 "src/frontc/clexer.mll"
        ( E.newline (); initial lexbuf)
# 1972 "src/frontc/clexer.ml"

  | 1 ->
# 512 "src/frontc/clexer.mll"
         ( hash lexbuf)
# 1977 "src/frontc/clexer.ml"

  | 2 ->
# 513 "src/frontc/clexer.mll"
         ( (* We are seeing a line number. This is the number for the 
                   * next line *)
                  E.setCurrentLine (int_of_string (Lexing.lexeme lexbuf) - 1);
                  (* A file name must follow *)
		  file lexbuf )
# 1986 "src/frontc/clexer.ml"

  | 3 ->
# 518 "src/frontc/clexer.mll"
                ( hash lexbuf )
# 1991 "src/frontc/clexer.ml"

  | 4 ->
# 521 "src/frontc/clexer.mll"
                           ( let here = currentLoc () in
                             PRAGMA_LINE ("warning" ^ pragma lexbuf, here)
                           )
# 1998 "src/frontc/clexer.ml"

  | 5 ->
# 524 "src/frontc/clexer.mll"
                           ( let here = currentLoc () in
                             PRAGMA_LINE ("GCC" ^ pragma lexbuf, here)
                           )
# 2005 "src/frontc/clexer.ml"

  | 6 ->
# 528 "src/frontc/clexer.mll"
                             ( let here = currentLoc () in
                             PRAGMA_LINE ("ident" ^ pragma lexbuf, here)
                           )
# 2012 "src/frontc/clexer.ml"

  | 7 ->
# 531 "src/frontc/clexer.mll"
                               ( let here = currentLoc () in
                                  PRAGMA_LINE ("section" ^ pragma lexbuf, here)
                            )
# 2019 "src/frontc/clexer.ml"

  | 8 ->
# 534 "src/frontc/clexer.mll"
                              ( let here = currentLoc () in
                                  PRAGMA_LINE ("option" ^ pragma lexbuf, here)
                            )
# 2026 "src/frontc/clexer.ml"

  | 9 ->
# 537 "src/frontc/clexer.mll"
                           ( let here = currentLoc () in
                                  PRAGMA_LINE ("asm" ^ pragma lexbuf, here)
                            )
# 2033 "src/frontc/clexer.ml"

  | 10 ->
# 540 "src/frontc/clexer.mll"
                                   ( let here = currentLoc () in
                                  PRAGMA_LINE ("use_section" ^ pragma lexbuf, here)
                            )
# 2040 "src/frontc/clexer.ml"

  | 11 ->
# 543 "src/frontc/clexer.mll"
                            ( let here = currentLoc () in
                                  PRAGMA_LINE ("weak" ^ pragma lexbuf, here)
                            )
# 2047 "src/frontc/clexer.ml"

  | 12 ->
# 547 "src/frontc/clexer.mll"
                ( let here = currentLoc () in
                  PRAGMA_LINE ("redefine_extname" ^ pragma lexbuf, here)
                 )
# 2054 "src/frontc/clexer.ml"

  | 13 ->
# 551 "src/frontc/clexer.mll"
                ( pragmaLine := true; PRAGMA (currentLoc ()) )
# 2059 "src/frontc/clexer.ml"

  | 14 ->
# 552 "src/frontc/clexer.mll"
            ( endline lexbuf)
# 2064 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_hash_rec lexbuf __ocaml_lex_state

and file lexbuf =
    __ocaml_lex_file_rec lexbuf 250
and __ocaml_lex_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 555 "src/frontc/clexer.mll"
                      (E.newline (); initial lexbuf)
# 2075 "src/frontc/clexer.ml"

  | 1 ->
# 556 "src/frontc/clexer.mll"
          (file lexbuf)
# 2080 "src/frontc/clexer.ml"

  | 2 ->
# 557 "src/frontc/clexer.mll"
                                ( (* '"' *)
                                   let n = Lexing.lexeme lexbuf in
                                   let n1 = String.sub n 1 
                                       ((String.length n) - 2) in
                                   E.setCurrentFile n1;
				 endline lexbuf)
# 2090 "src/frontc/clexer.ml"

  | 3 ->
# 564 "src/frontc/clexer.mll"
      (endline lexbuf)
# 2095 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_file_rec lexbuf __ocaml_lex_state

and endline lexbuf =
    __ocaml_lex_endline_rec lexbuf 254
and __ocaml_lex_endline_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 567 "src/frontc/clexer.mll"
                ( E.newline (); initial lexbuf)
# 2106 "src/frontc/clexer.ml"

  | 1 ->
# 568 "src/frontc/clexer.mll"
                                ( EOF )
# 2111 "src/frontc/clexer.ml"

  | 2 ->
# 569 "src/frontc/clexer.mll"
      ( endline lexbuf)
# 2116 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_endline_rec lexbuf __ocaml_lex_state

and pragma lexbuf =
    __ocaml_lex_pragma_rec lexbuf 255
and __ocaml_lex_pragma_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 572 "src/frontc/clexer.mll"
                        ( E.newline (); "" )
# 2127 "src/frontc/clexer.ml"

  | 1 ->
# 573 "src/frontc/clexer.mll"
                        ( let cur = Lexing.lexeme lexbuf in 
                          cur ^ (pragma lexbuf) )
# 2133 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_pragma_rec lexbuf __ocaml_lex_state

and str lexbuf =
    __ocaml_lex_str_rec lexbuf 256
and __ocaml_lex_str_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 577 "src/frontc/clexer.mll"
                        ([])
# 2144 "src/frontc/clexer.ml"

  | 1 ->
# 578 "src/frontc/clexer.mll"
             (lex_hex_escape str lexbuf)
# 2149 "src/frontc/clexer.ml"

  | 2 ->
# 579 "src/frontc/clexer.mll"
             (lex_oct_escape str lexbuf)
# 2154 "src/frontc/clexer.ml"

  | 3 ->
# 580 "src/frontc/clexer.mll"
          (lex_simple_escape str lexbuf)
# 2159 "src/frontc/clexer.ml"

  | 4 ->
# 581 "src/frontc/clexer.mll"
     (lex_unescaped str lexbuf)
# 2164 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_str_rec lexbuf __ocaml_lex_state

and chr lexbuf =
    __ocaml_lex_chr_rec lexbuf 262
and __ocaml_lex_chr_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 584 "src/frontc/clexer.mll"
              ([])
# 2175 "src/frontc/clexer.ml"

  | 1 ->
# 585 "src/frontc/clexer.mll"
             (lex_hex_escape chr lexbuf)
# 2180 "src/frontc/clexer.ml"

  | 2 ->
# 586 "src/frontc/clexer.mll"
             (lex_oct_escape chr lexbuf)
# 2185 "src/frontc/clexer.ml"

  | 3 ->
# 587 "src/frontc/clexer.mll"
          (lex_simple_escape chr lexbuf)
# 2190 "src/frontc/clexer.ml"

  | 4 ->
# 588 "src/frontc/clexer.mll"
     (lex_unescaped chr lexbuf)
# 2195 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_chr_rec lexbuf __ocaml_lex_state

and msasm lexbuf =
    __ocaml_lex_msasm_rec lexbuf 268
and __ocaml_lex_msasm_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 591 "src/frontc/clexer.mll"
                        ( msasm lexbuf )
# 2206 "src/frontc/clexer.ml"

  | 1 ->
# 592 "src/frontc/clexer.mll"
                        ( msasminbrace lexbuf )
# 2211 "src/frontc/clexer.ml"

  | 2 ->
# 593 "src/frontc/clexer.mll"
                        ( let cur = Lexing.lexeme lexbuf in 
                          cur ^ (msasmnobrace lexbuf) )
# 2217 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_msasm_rec lexbuf __ocaml_lex_state

and msasminbrace lexbuf =
    __ocaml_lex_msasminbrace_rec lexbuf 270
and __ocaml_lex_msasminbrace_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 597 "src/frontc/clexer.mll"
                        ( "" )
# 2228 "src/frontc/clexer.ml"

  | 1 ->
# 598 "src/frontc/clexer.mll"
                        ( let cur = Lexing.lexeme lexbuf in 
                          cur ^ (msasminbrace lexbuf) )
# 2234 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_msasminbrace_rec lexbuf __ocaml_lex_state

and msasmnobrace lexbuf =
    __ocaml_lex_msasmnobrace_rec lexbuf 271
and __ocaml_lex_msasmnobrace_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 601 "src/frontc/clexer.mll"
                        ( lexbuf.Lexing.lex_curr_pos <- 
                               lexbuf.Lexing.lex_curr_pos - 1;
                          "" )
# 2247 "src/frontc/clexer.ml"

  | 1 ->
# 604 "src/frontc/clexer.mll"
                        ( lexbuf.Lexing.lex_curr_pos <- 
                               lexbuf.Lexing.lex_curr_pos - 5;
                          "" )
# 2254 "src/frontc/clexer.ml"

  | 2 ->
# 607 "src/frontc/clexer.mll"
                        ( let cur = Lexing.lexeme lexbuf in 

                          cur ^ (msasmnobrace lexbuf) )
# 2261 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_msasmnobrace_rec lexbuf __ocaml_lex_state

and attribute lexbuf =
    __ocaml_lex_attribute_rec lexbuf 276
and __ocaml_lex_attribute_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 612 "src/frontc/clexer.mll"
                        ( E.newline (); attribute lexbuf )
# 2272 "src/frontc/clexer.ml"

  | 1 ->
# 613 "src/frontc/clexer.mll"
                        ( attribute lexbuf )
# 2277 "src/frontc/clexer.ml"

  | 2 ->
# 614 "src/frontc/clexer.mll"
                        ( incr attribDepth; LPAREN (currentLoc ()) )
# 2282 "src/frontc/clexer.ml"

  | 3 ->
# 615 "src/frontc/clexer.mll"
                        ( decr attribDepth;
                          if !attribDepth = 0 then
                            initial lexbuf (* Skip the last closed paren *)
                          else
                            RPAREN )
# 2291 "src/frontc/clexer.ml"

  | 4 ->
# 620 "src/frontc/clexer.mll"
                        ( IDENT (Lexing.lexeme lexbuf, currentLoc ()) )
# 2296 "src/frontc/clexer.ml"

  | 5 ->
# 622 "src/frontc/clexer.mll"
          ( CST_CHAR (chr lexbuf, currentLoc ()))
# 2301 "src/frontc/clexer.ml"

  | 6 ->
# 623 "src/frontc/clexer.mll"
         ( (* '"' *)
                                          try CST_STRING (str lexbuf, currentLoc ())
                                          with e -> 
                                             raise (InternalError "str"))
# 2309 "src/frontc/clexer.ml"

  | 7 ->
# 627 "src/frontc/clexer.mll"
             (CST_FLOAT (Lexing.lexeme lexbuf, currentLoc ()))
# 2314 "src/frontc/clexer.ml"

  | 8 ->
# 628 "src/frontc/clexer.mll"
           (CST_INT (Lexing.lexeme lexbuf, currentLoc ()))
# 2319 "src/frontc/clexer.ml"

  | 9 ->
# 629 "src/frontc/clexer.mll"
           (CST_INT (Lexing.lexeme lexbuf, currentLoc ()))
# 2324 "src/frontc/clexer.ml"

  | 10 ->
# 630 "src/frontc/clexer.mll"
           (CST_INT (Lexing.lexeme lexbuf, currentLoc ()))
# 2329 "src/frontc/clexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_attribute_rec lexbuf __ocaml_lex_state

;;

# 633 "src/frontc/clexer.mll"
 


# 2339 "src/frontc/clexer.ml"
